@@ -96,6 +96,7 @@
 #include <stdio.h>
 #include <pwd.h>
 #include <string.h>
+#include <ctype.h>
 #include <signal.h>
 #include <netdb.h>
 #include <unistd.h>
@@ -1195,6 +1196,8 @@ int pbs_connect(char *server_name_ptr)    /* I (optional) */
   if (server_name_ptr && server_name_ptr[0])
     {
     strncpy(server_name_list, server_name_ptr, sizeof(server_name_list) - 1);
+    strcat(server_name_list, ",");
+    strncat(server_name_list, pbs_get_server_list(), sizeof(server_name_list) -1 - strlen(server_name_ptr) - 1);
 
     if (getenv("PBSDEBUG"))
       {
@@ -1221,6 +1224,9 @@ int pbs_connect(char *server_name_ptr)    /* I (optional) */
 
     if (tp && tp[0])
       {
+      /* Trim any leading space */
+      while(isspace(*tp)) tp++;
+
       memset(current_name, 0, sizeof(current_name));
       strncpy(current_name, tp, sizeof(current_name) - 1);
 
