@@ -663,7 +663,7 @@ static int tcp_puts(
     /* not enough room, reallocate the buffer */
     leadpct = (int)(tp->tdis_thebuf - tp->tdis_leadp);
     trailpct = (int)(tp->tdis_thebuf - tp->tdis_trailp);
-    newbufsize = tp->tdis_bufsize + THE_BUF_SIZE + ct;
+    newbufsize = tp->tdis_bufsize + THE_BUF_SIZE + ct; /* grow by ct + THE_BUF_SIZE */
     temp = (char *)malloc(newbufsize);
     if(!temp)
       {
