@@ -109,8 +109,6 @@
 
 /* External Globals */
 
-extern struct connection svr_conn[];
-
 extern char *msg_daemonname;
 
 #ifndef PBS_MOM
@@ -275,10 +273,8 @@ int reply_send(
     /* Otherwise, the reply is to be sent to a remote client */
 
 #ifndef PBS_MOM
-#ifdef AUTORUN_JOBS
     if (request->rq_noreply != TRUE)
       {
-#endif
 #endif
       rc = dis_reply_write(sfds, &request->rq_reply);
 #ifndef PBS_MOM
@@ -294,7 +290,7 @@ int reply_send(
           id,
           log_buffer);
         }
-#ifdef AUTORUN_JOBS
+#ifndef PBS_MOM
       }
 
 #endif
@@ -324,14 +320,13 @@ int reply_send(
  * Always frees the request structure.
  */
 
-void
-reply_ack(struct batch_request *preq)
+void reply_ack(struct batch_request *preq)
   {
 
   preq->rq_reply.brp_code    = PBSE_NONE;
   preq->rq_reply.brp_auxcode = 0;
   preq->rq_reply.brp_choice  = BATCH_REPLY_CHOICE_NULL;
-  (void)reply_send(preq);
+  reply_send(preq);
   }
 
 /*
