@@ -168,15 +168,17 @@ static char *all_nodes = "_All_";
  * Returns: NULL if all ok or name of bad attribute if not ok
  */
 
-static char *
-check_que_attr(pbs_queue *pque)
+static char *check_que_attr(
+    
+  pbs_queue *pque)
+
   {
   int   i;
   int   type;
 
   type = pque->qu_qs.qu_type;  /* current type of queue */
 
-  for (i = 0; i < (int)QA_ATR_LAST; ++i)
+  for (i = 0; i < QA_ATR_LAST; ++i)
     {
     if (pque->qu_attr[i].at_flags & ATR_VFLAG_SET)
       {
@@ -199,19 +201,19 @@ check_que_attr(pbs_queue *pque)
     }
 
   return ((char *)0); /* all attributes are ok */
-  }
+  } /* END check_que_attr() */
 
 /*
  * check_que_enable - check if attempt to enable incompletely defined queue
  * This is the at_action() routine for QA_ATR_Enabled
  */
 
-int
-check_que_enable(
+int check_que_enable(
+
   attribute *pattr,
   void *pque, /* actually a queue* */
-  int mode
-)
+  int mode)
+
   {
   attribute *datr;
 
@@ -227,7 +229,7 @@ check_que_enable(
       return (PBSE_QUENOEN);
     else if (((pbs_queue *)pque)->qu_qs.qu_type == QTYPE_RoutePush)
       {
-      datr = &((pbs_queue *)pque)->qu_attr[(int)QR_ATR_RouteDestin];
+      datr = &((pbs_queue *)pque)->qu_attr[QR_ATR_RouteDestin];
 
       if (!(datr->at_flags & ATR_VFLAG_SET) ||
           (datr->at_val.at_arst->as_usedptr == 0))
@@ -235,8 +237,11 @@ check_que_enable(
       }
     }
 
-  return (0); /* ok to enable queue */
-  }
+  return(PBSE_NONE); /* ok to enable queue */
+  } /* END check_que_enable() */
+
+
+
 
 /*
  * set_queue_type - check the requested value of the queue type attribute
@@ -244,8 +249,12 @@ check_que_enable(
  * This is the at_action() routine for QA_ATR_QType
  */
 
-int
-set_queue_type(attribute *pattr, void *pque, int mode)
+int set_queue_type(
+    
+  attribute *pattr,
+  void *pque,
+  int mode)
+
   {
   int   i;
   char *pca;
@@ -298,25 +307,27 @@ set_queue_type(attribute *pattr, void *pque, int mode)
 
       (void)strcpy(pattr->at_val.at_str, qt[i].name);
 
-      return (0);
+      return(PBSE_NONE);
       }
     }
 
   return (PBSE_BADATVAL);
-  }
+  } /* set_queue_type() */
+
+
 
 
 /*
  * mgr_log_attr - log the change of an attribute
  */
 
-static void
-mgr_log_attr(
+static void mgr_log_attr(
+
   char *msg,
   struct svrattrl *plist,
-  int logclass, /* see log.h */
-  char *objname /* object being modified */
-)
+  int logclass,           /* see log.h */
+  char *objname)          /* object being modified */
+
   {
   char *pstr;
 
@@ -350,7 +361,7 @@ mgr_log_attr(
 
     plist = (struct svrattrl *)GET_NEXT(plist->al_link);
     }
-  }
+  } /* END mgr_log_attr() */
 
 
 
@@ -562,7 +573,7 @@ int mgr_unset_attr(
       if ((presc = find_resc_entry(pattr + index, prsdef)))
         {
         if ((pdef->at_parent != PARENT_TYPE_SERVER) ||
-            (index != (int)SRV_ATR_resource_cost))
+            (index != SRV_ATR_resource_cost))
           {
           prsdef->rs_free(&presc->rs_value);
           }
@@ -666,6 +677,7 @@ int mgr_set_node_attr(
   void  *parent, /*may go unused in this function */
   int   mode)  /*passed to attrib's action func */
 /*not used by this func at this time*/
+
   {
   int   i;
   int   index;
@@ -1017,7 +1029,7 @@ void mgr_queue_create(
     }
 
   return;
-  }
+  } /* END mgr_queue_create() */
 
 
 
@@ -1093,7 +1105,7 @@ int hostname_check(
 
   if (hostname == NULL)
     return(SUCCESS);
-  else if(strchr(hostname,'*') != NULL)
+  else if (strchr(hostname,'*') != NULL)
     return(SUCCESS);
 
   strcpy(myhost,hostname);
@@ -1258,7 +1270,7 @@ void mgr_server_set(
       /* nothing wrong found in the request, let's try again
          with the server's list */
 
-      pstr = server.sv_attr[(int)index].at_val.at_arst;
+      pstr = server.sv_attr[index].at_val.at_arst;
 
       for (i = 0; i < pstr->as_usedptr; ++i)
         {
@@ -1575,7 +1587,7 @@ void mgr_queue_unset(
 
     mgr_log_attr(msg_man_uns, plist, PBS_EVENTCLASS_QUEUE, pque->qu_qs.qu_name);
 
-    if ((pque->qu_attr[(int)QA_ATR_QType].at_flags & ATR_VFLAG_SET) == 0)
+    if ((pque->qu_attr[QA_ATR_QType].at_flags & ATR_VFLAG_SET) == 0)
       pque->qu_qs.qu_type = QTYPE_Unset;
 
     if (allques == FALSE)
@@ -1612,7 +1624,7 @@ void mgr_node_set(
   int  bad = 0;
   svrattrl *plist;
 
-  struct pbsnode  *pnode;
+  struct pbsnode  *pnode = NULL;
   char  *nodename = NULL;
   int  rc;
 
@@ -1620,6 +1632,8 @@ void mgr_node_set(
   int  problem_cnt = 0;
   char  *problem_names;
 
+  node_iterator iter;
+
   struct pbsnode  **problem_nodes = NULL;
 
   struct prop props;
@@ -1680,22 +1694,61 @@ void mgr_node_set(
 
   log_event(PBSEVENT_ADMIN, PBS_EVENTCLASS_NODE, nodename, log_buffer);
 
+  plist = (svrattrl *)GET_NEXT(preq->rq_ind.rq_manager.rq_attr);
+
   if (allnodes || propnodes)
     {
-    pnode = pbsndlist[0];
+    /* handle scrolling over all nodes */
 
     problem_nodes = (struct pbsnode **)malloc(svr_totnodes * sizeof(struct pbsnode *));
 
     problem_cnt = 0;
-    }
+  
+    reinitialize_node_iterator(&iter);
 
-  plist = (svrattrl *)GET_NEXT(preq->rq_ind.rq_manager.rq_attr);
+    while ((pnode = next_node(&iter)) != NULL)
+      {
+      if (propnodes && !hasprop(pnode, &props))
+        continue;
 
-  for (i = 0;i < svr_totnodes;i++, pnode = pbsndlist[i])
+      save_characteristic(pnode);
+
+      rc = mgr_set_node_attr(
+             pnode,
+             node_attr_def,
+             ND_ATR_LAST,
+             plist,
+             preq->rq_perm,
+             &bad,
+             (void *)pnode,
+             ATR_ACTION_ALTER);
+
+      if (rc != 0)
+        {
+        if (problem_nodes)     /*we have an array in which to save*/
+          problem_nodes[ problem_cnt ] = pnode;
+        
+        ++problem_cnt;
+        }
+      else
+        {
+        /* modifications succeeded for this node */
+
+        chk_characteristic(pnode, &need_todo);
+
+        mgr_log_attr(
+          msg_man_set,
+          plist,
+          PBS_EVENTCLASS_NODE,
+          pnode->nd_name);
+        }
+
+      }  /* END for each node */
+
+    } /* END multiple node case */
+  else
     {
-    if (propnodes && !hasprop(pnode, &props))
-      continue;
-
+    /* handle single node case */
     save_characteristic(pnode);
 
     rc = mgr_set_node_attr(
@@ -1710,66 +1763,52 @@ void mgr_node_set(
 
     if (rc != 0)
       {
-      if (allnodes || propnodes)
+      /*In the specific node case, reply w/ error and return*/
+      
+      switch (rc)
         {
-        if (problem_nodes)     /*we have an array in which to save*/
-          problem_nodes[ problem_cnt ] = pnode;
+        case PBSE_INTERNAL:
+          
+        case PBSE_SYSTEM:
 
-        ++problem_cnt;
+          req_reject(rc, bad, preq, NULL, NULL);
+          
+          break;
+
+        case PBSE_NOATTR:
+          
+        case PBSE_ATTRRO:
+          
+        case PBSE_MUTUALEX:
+          
+        case PBSE_BADNDATVAL:
+          
+          reply_badattr(rc, bad, plist, preq);
+          
+          break;
+          
+        default:
+          
+          req_reject(rc, 0, preq, NULL, NULL);
+          
+          break;
         }
-      else
-        {
-        /*In the specific node case, reply w/ error and return*/
 
-        switch (rc)
-          {
-
-          case PBSE_INTERNAL:
-
-          case PBSE_SYSTEM:
-
-            req_reject(rc, bad, preq, NULL, NULL);
-
-            break;
-
-          case PBSE_NOATTR:
-
-          case PBSE_ATTRRO:
-
-          case PBSE_MUTUALEX:
-
-          case PBSE_BADNDATVAL:
-
-            reply_badattr(rc, bad, plist, preq);
-
-            break;
-
-          default:
-
-            req_reject(rc, 0, preq, NULL, NULL);
-
-            break;
-          }
-
-        return;
-        }  /* END else */
-      }
+      return;
+      } /* END if (rc != 0) */ 
     else
       {
       /* modifications succeeded for this node */
-
+      
       chk_characteristic(pnode, &need_todo);
-
+      
       mgr_log_attr(
         msg_man_set,
         plist,
         PBS_EVENTCLASS_NODE,
         pnode->nd_name);
       }
-
-    if (!allnodes && !propnodes)
-      break;
-    }  /* END for (i) */
+    } /* END single node case */
 
   if (need_todo & WRITENODE_STATE)
     {
@@ -1886,6 +1925,8 @@ static void mgr_node_delete(
   struct pbsnode  **problem_nodes = NULL;
   svrattrl *plist;
 
+  node_iterator iter;
+
   if ((*preq->rq_ind.rq_manager.rq_objname == '\0') ||
       (*preq->rq_ind.rq_manager.rq_objname == '@'))
     {
@@ -1927,38 +1968,32 @@ static void mgr_node_delete(
 
   log_event(PBSEVENT_ADMIN, PBS_EVENTCLASS_NODE, nodename, log_buffer);
 
+  plist = (svrattrl *)GET_NEXT(preq->rq_ind.rq_manager.rq_attr);
+
   /*if doing many and problem arises with some, record them for report*/
   /*the array of "problem nodes" sees no use now and may never see use*/
 
   if (allnodes)
     {
-    pnode = pbsndlist[0];
-
+    /* handle all nodes */
     problem_nodes = (struct pbsnode **)malloc(
                       svr_totnodes * sizeof(struct pbsnode *));
 
     problem_cnt = 0;
-    }
 
-  /*set "deleted" bit in node's (nodes, allnodes == 1) "inuse" field*/
-  /*remove entire prop list, including the node name, from the node */
-  /*remove the IP address array hanging from the node               */
+    reinitialize_node_iterator(&iter);
 
-  plist = (svrattrl *)GET_NEXT(preq->rq_ind.rq_manager.rq_attr);
-
-  for (i = 0;i < svr_totnodes;i++, pnode = pbsndlist[i])
-    {
-    save_characteristic(pnode);
-
-    nodename = strdup(pnode->nd_name);
-
-    effective_node_delete(pnode);
-
-    rc = 0;   /*currently, failure not possible so set rc=0   */
-
-    if (rc != 0)
+    while ((pnode = next_node(&iter)) != NULL)
       {
-      if (allnodes)
+      save_characteristic(pnode);
+
+      nodename = strdup(pnode->nd_name);
+
+      effective_node_delete(pnode);
+
+      rc = 0;   /*currently, failure not possible so set rc=0   */
+
+      if (rc != 0)
         {
         if (problem_nodes)     /*we have an array in which to save*/
           problem_nodes[problem_cnt] = pnode;
@@ -1967,20 +2002,46 @@ static void mgr_node_delete(
         }
       else
         {
-        /*In the specific node case, reply w/ error and return*/
+        /*modifications succeed for this node*/
 
-        switch (rc)
+        chk_characteristic(pnode, &need_todo);
+
+        if (nodename)
           {
+          mgr_log_attr(msg_man_set, plist, PBS_EVENTCLASS_NODE, nodename);
 
-          default:
-
-            req_reject(rc, 0, preq, NULL, NULL);
-
-            break;
+          free(nodename);
           }
-
-        return;
         }
+
+      } /* end loop ( all nodes ) */
+    }
+  else
+    {
+    /* handle single nodes */
+    save_characteristic(pnode);
+
+    nodename = strdup(pnode->nd_name);
+
+    effective_node_delete(pnode);
+
+    rc = 0;   /*currently, failure not possible so set rc=0   */
+        
+    if (rc != 0)
+      {
+      /*In the specific node case, reply w/ error and return*/
+      
+      switch (rc)
+        {
+        
+        default:
+          
+          req_reject(rc, 0, preq, NULL, NULL);
+          
+          break;
+        }
+
+      return;
       }
     else
       {
@@ -1995,10 +2056,12 @@ static void mgr_node_delete(
         free(nodename);
         }
       }
+    }
+
+  /*set "deleted" bit in node's (nodes, allnodes == 1) "inuse" field*/
+  /*remove entire prop list, including the node name, from the node */
+  /*remove the IP address array hanging from the node               */
 
-    if (!allnodes)
-      break;
-    } /* bottom of the for() */
 
   if (need_todo & WRITENODE_STATE)
     {
@@ -2469,6 +2532,7 @@ int servername_chk(
 void on_extra_resc(
 
   struct work_task *ptask)
+
   {
   init_resc_defs();
   }
@@ -2574,7 +2638,7 @@ int disallowed_types_chk(
 static int mgr_long_action_helper(
 
   attribute *pattr,
-  int      actmode,
+  int        actmode,
   long       minimum,
   long       maximum)
 
@@ -2615,7 +2679,7 @@ int schiter_chk(
 
   attribute *pattr,
   void      *pobject,
-  int      actmode)
+  int        actmode)
 
   {
   return(mgr_long_action_helper(pattr, actmode, 1, PBS_SCHEDULE_CYCLE));
