@@ -126,7 +126,7 @@ int svr_chk_owner(
   {
   char  owner[PBS_MAXUSER + 1];
 
-  get_jobowner(pjob->ji_wattr[(int)JOB_ATR_job_owner].at_val.at_str, owner);
+  get_jobowner(pjob->ji_wattr[JOB_ATR_job_owner].at_val.at_str, owner);
 
 
   return svr_chk_owner_generic(preq, owner, get_variable(pjob, pbs_o_host));
@@ -183,7 +183,7 @@ int svr_authorize_jobreq(
   {
   char  owner[PBS_MAXUSER + 1];
 
-  get_jobowner(pjob->ji_wattr[(int)JOB_ATR_job_owner].at_val.at_str, owner);
+  get_jobowner(pjob->ji_wattr[JOB_ATR_job_owner].at_val.at_str, owner);
 
   return svr_authorize_req(preq, owner, get_variable(pjob, pbs_o_host));
   }  /* END svr_authorize_jobreq() */
@@ -259,7 +259,7 @@ int svr_get_privilege(
   char  host_no_port[PBS_MAXHOSTNAME+1];
   char *colon_loc = NULL;
 
-  if(!user)
+  if (!user)
     {
 
     sprintf(log_buffer, "Invalid user: %s", "null");
@@ -275,7 +275,7 @@ int svr_get_privilege(
     }
 
   /* user name cannot be longer than PBS_MAXUSER*/
-  if(strlen(user) > PBS_MAXUSER)
+  if (strlen(user) > PBS_MAXUSER)
     {
     sprintf(log_buffer, "Invalid user: %s", user);
 
@@ -288,7 +288,7 @@ int svr_get_privilege(
     return(0);
     }
 
-  if(!host)
+  if (!host)
     return(0);
 
   colon_loc = strchr(host, ':');
@@ -353,7 +353,7 @@ int svr_get_privilege(
     }
 #endif /* __CYGWIN__ */
 
-  if (!(server.sv_attr[(int)SRV_ATR_managers].at_flags & ATR_VFLAG_SET))
+  if (!(server.sv_attr[SRV_ATR_managers].at_flags & ATR_VFLAG_SET))
     {
     if (is_root)
       priv |= (ATR_DFLAG_MGRD | ATR_DFLAG_MGWR);
@@ -363,7 +363,7 @@ int svr_get_privilege(
     priv |= (ATR_DFLAG_MGRD | ATR_DFLAG_MGWR);
     }
 
-  if (!(server.sv_attr[(int)SRV_ATR_operators].at_flags & ATR_VFLAG_SET))
+  if (!(server.sv_attr[SRV_ATR_operators].at_flags & ATR_VFLAG_SET))
     {
     if (is_root)
       priv |= (ATR_DFLAG_OPRD | ATR_DFLAG_OPWR);
@@ -390,7 +390,8 @@ int svr_get_privilege(
 int authenticate_user(
 
   struct batch_request *preq,  /* I */
-  struct credential    *pcred) /* I */
+  struct credential    *pcred,
+  char   **autherr) /* O */
 
   {
   char id[] = "authenticate_user";
@@ -398,10 +399,33 @@ int authenticate_user(
   char uath[PBS_MAXUSER + PBS_MAXHOSTNAME + 1];
   char error_msg[1024];
 
+#ifdef MUNGE_AUTH
   if (strncmp(preq->rq_user, pcred->username, PBS_MAXUSER))
     {
-    sprintf(error_msg, "Users do not match: Requested user %s: credential user: %s",
-                   preq->rq_user, pcred->username);
+    /* extra check for munge */
+    char uh[PBS_MAXUSER + PBS_MAXHOSTNAME + 2];
+
+    sprintf(uh, "%s@%s", preq->rq_user, pcred->hostname);
+    
+    if ((acl_check(&server.sv_attr[SRV_ATR_authusers], uh, ACL_User_Host)) == 0)
+      {
+      *autherr = strdup("User not in authorized user list.");
+      sprintf(error_msg, "%s Requested user %s: requested from host %s",
+                     *autherr, preq->rq_user, preq->rq_host);
+      log_event(
+        PBSEVENT_ADMIN,
+        PBS_EVENTCLASS_SERVER,
+        id,
+        error_msg);
+      return(PBSE_BADCRED);
+      }
+    }
+#else
+  if (strncmp(preq->rq_user, pcred->username, PBS_MAXUSER))
+    {
+    *autherr = strdup("Users do not match");
+    sprintf(error_msg, "%s: Requested user %s: credential user %s: requested from host %s",
+                   *autherr, preq->rq_user, pcred->username, preq->rq_host);
     log_event(
       PBSEVENT_ADMIN,
       PBS_EVENTCLASS_SERVER,
@@ -409,11 +433,13 @@ int authenticate_user(
       error_msg);
     return(PBSE_BADCRED);
     }
+#endif
 
   if (strncmp(preq->rq_host, pcred->hostname, PBS_MAXHOSTNAME))
     {
-    sprintf(error_msg, "Hosts do not match: Requested host %s: credential host: %s",
-                   preq->rq_host, pcred->hostname);
+    *autherr = strdup("Hosts do not match");
+    sprintf(error_msg, "%s: Requested host %s: credential host: %s",
+                   *autherr, preq->rq_host, pcred->hostname);
     log_event(
       PBSEVENT_ADMIN,
       PBS_EVENTCLASS_SERVER,
